@@ -9,11 +9,14 @@
 
 package org.gnu.gnome;
 import org.gnu.gdk.Pixbuf;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  * The About widget dialog window is designed to pop up from the
  * About button on an application menu. Its purpose is to standardize
  * the form and content.
+ * 
+ * @deprecated
  */
 public class About extends org.gnu.gtk.Dialog {
 
@@ -32,10 +35,10 @@ public class About extends org.gnu.gtk.Dialog {
 		super(init(title, version, license, comments, authors, documenters, translator, pixbuf));
 	}
 	
-	private static int init(String title, String version, String license, String comments, String authors[], String documenters[], String translator, Pixbuf pixbuf) {
-		int pixbufHandle;
+	private static Handle init(String title, String version, String license, String comments, String authors[], String documenters[], String translator, Pixbuf pixbuf) {
+		Handle pixbufHandle;
 		if (pixbuf == null) {
-			pixbufHandle = 0;
+			pixbufHandle = null;
 		} else {
 			pixbufHandle = pixbuf.getHandle();
 		}
@@ -46,7 +49,7 @@ public class About extends org.gnu.gtk.Dialog {
 	/**
 	 * Construct an About box using a handle to a native resource.
 	 */
-	public About(int handle) {
+	public About(Handle handle) {
 	    super(handle);
 	}
 
@@ -57,11 +60,9 @@ public class About extends org.gnu.gtk.Dialog {
 		return new Type(gnome_about_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_about_get_type();
-	native static final protected int gnome_about_new(
+	native static final protected Handle gnome_about_new(
 		String title,
 		String version,
 		String copyright,
@@ -69,8 +70,6 @@ public class About extends org.gnu.gtk.Dialog {
 		String [] authors,
 		String [] documenters,
 		String translatorCredits,
-		int logo);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+		Handle logo);
+
 }
