@@ -8,17 +8,23 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  * A GnomeCanvasPolygon is a GnomeCanvasItem that draws a filled
  * polygon on a GnomeCanvas.
  */
 public class CanvasPolygon extends CanvasShape {
+
+	public CanvasPolygon(CanvasGroup group) {
+		super(group, gnome_canvas_polygon_get_type());
+	}
+
 	/**
 	 * Constructs an instance of CanvasPolygon from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasPolygon(int handle) {
+	CanvasPolygon(Handle handle) {
 		super(handle);
 	}
 
@@ -29,11 +35,7 @@ public class CanvasPolygon extends CanvasShape {
 		return new Type(gnome_canvas_polygon_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_polygon_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
