@@ -9,6 +9,7 @@
 
 package org.gnu.gnome;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Container;
@@ -31,7 +32,7 @@ public class Druid extends Container {
 	/**
 	 * Construct a new Druid from a handle to a native resource.
 	 */
-	public Druid(int handle) {
+	public Druid(Handle handle) {
 	    super(handle);
 	}
 	
@@ -108,7 +109,7 @@ public class Druid extends Container {
 	 * Retrieve the "Help" button.
 	 */
 	public Button getHelpButton() {
-		int hndl = getHelp(getHandle());
+		Handle hndl = getHelp(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Button)obj;
@@ -119,7 +120,7 @@ public class Druid extends Container {
 	 * Retrieve the "Back" button.
 	 */
 	public Button getBackButton() {
-		int hndl = getBack(getHandle());
+		Handle hndl = getBack(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Button)obj;
@@ -130,7 +131,7 @@ public class Druid extends Container {
 	 * Retrieve the "Next" button.
 	 */
 	public Button getNextButton() {
-		int hndl = getNext(getHandle());
+		Handle hndl = getNext(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Button)obj;
@@ -141,7 +142,7 @@ public class Druid extends Container {
 	 * Retrieve the "Cancel" button.
 	 */
 	public Button getCancelButton() {
-		int hndl = getCancel(getHandle());
+		Handle hndl = getCancel(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Button)obj;
@@ -152,7 +153,7 @@ public class Druid extends Container {
 	 * Retrieve the "Finish" button.
 	 */
 	public Button getFinishButton() {
-		int hndl = getFinish(getHandle());
+		Handle hndl = getFinish(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Button)obj;
@@ -165,25 +166,21 @@ public class Druid extends Container {
 	public static Type getType() {
 		return new Type(gnome_druid_get_type());
 	}
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
-	native static final protected int getHelp(int cptr);
-	native static final protected int getBack(int cptr);
-	native static final protected int getNext(int cptr);
-	native static final protected int getCancel(int cptr);
-	native static final protected int getFinish(int cptr);
+
+	native static final protected Handle getHelp(Handle cptr);
+	native static final protected Handle getBack(Handle cptr);
+	native static final protected Handle getNext(Handle cptr);
+	native static final protected Handle getCancel(Handle cptr);
+	native static final protected Handle getFinish(Handle cptr);
 	native static final protected int gnome_druid_get_type();
-	native static final protected int gnome_druid_new();
-	native static final protected void gnome_druid_set_buttons_sensitive(int druid, boolean backSensitive, boolean nextSensitive, boolean cancelSensitive, boolean helpSensitive);
-	native static final protected void gnome_druid_set_show_finish(int druid, boolean showFinish);
-	native static final protected void gnome_druid_set_show_help(int druid, boolean showHelp);
-	native static final protected void gnome_druid_prepend_page(int druid, int page);
-	native static final protected void gnome_druid_insert_page(int druid, int backPage, int page);
-	native static final protected void gnome_druid_append_page(int druid, int page);
-	native static final protected void gnome_druid_set_page(int druid, int page);
-	native static final protected int gnome_druid_new_with_window(String title, int parent, boolean closeOnCancel, int window);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_druid_new();
+	native static final protected void gnome_druid_set_buttons_sensitive(Handle druid, boolean backSensitive, boolean nextSensitive, boolean cancelSensitive, boolean helpSensitive);
+	native static final protected void gnome_druid_set_show_finish(Handle druid, boolean showFinish);
+	native static final protected void gnome_druid_set_show_help(Handle druid, boolean showHelp);
+	native static final protected void gnome_druid_prepend_page(Handle druid, Handle page);
+	native static final protected void gnome_druid_insert_page(Handle druid, Handle backPage, Handle page);
+	native static final protected void gnome_druid_append_page(Handle druid, Handle page);
+	native static final protected void gnome_druid_set_page(Handle druid, Handle page);
+	native static final protected Handle gnome_druid_new_with_window(String title, Handle parent, boolean closeOnCancel, Handle window);
+
 }
