@@ -11,6 +11,7 @@ package org.gnu.gnome;
 import org.gnu.gdk.Color;
 import org.gnu.gdk.Pixbuf;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.VBox;
 import org.gnu.gtk.Widget;
@@ -36,7 +37,7 @@ public class DruidPageStandard extends DruidPage {
 	 * Constructs a new DruidPageStandard object form a native resource.
 	 * @param handle The handle to the native resource.
 	 */
-	public DruidPageStandard(int handle) {
+	public DruidPageStandard(Handle handle) {
 	    super(handle);
 	}
 	
@@ -94,7 +95,7 @@ public class DruidPageStandard extends DruidPage {
 	 * the the main area of the page.
 	 */
 	public VBox getLayout() {
-		int hndl = getVbox(getHandle());
+		Handle hndl = getVbox(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (VBox)obj;
@@ -115,29 +116,25 @@ public class DruidPageStandard extends DruidPage {
 		return new Type(gnome_druid_page_standard_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
-	native static final protected int getVbox(int cptr);
-	native static final protected String getTitle(int cptr);
-	native static final protected int getLogo(int cptr);
-	native static final protected int getTopWatermark(int cptr);
-	native static final protected int getTitleForeground(int cptr);
-	native static final protected int getBackground(int cptr);
-	native static final protected int getLogoBackground(int cptr);
-	native static final protected int getContentsBackground(int cptr);
+
+	native static final protected Handle getVbox(Handle cptr);
+	native static final protected String getTitle(Handle cptr);
+	native static final protected Handle getLogo(Handle cptr);
+	native static final protected Handle getTopWatermark(Handle cptr);
+	native static final protected Handle getTitleForeground(Handle cptr);
+	native static final protected Handle getBackground(Handle cptr);
+	native static final protected Handle getLogoBackground(Handle cptr);
+	native static final protected Handle getContentsBackground(Handle cptr);
 	native static final protected int gnome_druid_page_standard_get_type();
-	native static final protected int gnome_druid_page_standard_new();
-	native static final protected int gnome_druid_page_standard_new_with_vals(String title, int logo, int topWatermark);
-	native static final protected void gnome_druid_page_standard_set_title(int page, String title);
-	native static final protected void gnome_druid_page_standard_set_logo(int page, int logoImage);
-	native static final protected void gnome_druid_page_standard_set_top_watermark(int page, int topWatermarkImage);
-	native static final protected void gnome_druid_page_standard_set_title_foreground(int page, int color);
-	native static final protected void gnome_druid_page_standard_set_background(int page, int color);
-	native static final protected void gnome_druid_page_standard_set_logo_background(int page, int color);
-	native static final protected void gnome_druid_page_standard_set_contents_background(int page, int color);
-	native static final protected void gnome_druid_page_standard_append_item(int page, String questionMnemonic, int item, String additionalInfoMarkup);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_druid_page_standard_new();
+	native static final protected Handle gnome_druid_page_standard_new_with_vals(String title, Handle logo, Handle topWatermark);
+	native static final protected void gnome_druid_page_standard_set_title(Handle page, String title);
+	native static final protected void gnome_druid_page_standard_set_logo(Handle page, Handle logoImage);
+	native static final protected void gnome_druid_page_standard_set_top_watermark(Handle page, Handle topWatermarkImage);
+	native static final protected void gnome_druid_page_standard_set_title_foreground(Handle page, Handle color);
+	native static final protected void gnome_druid_page_standard_set_background(Handle page, Handle color);
+	native static final protected void gnome_druid_page_standard_set_logo_background(Handle page, Handle color);
+	native static final protected void gnome_druid_page_standard_set_contents_background(Handle page, Handle color);
+	native static final protected void gnome_druid_page_standard_append_item(Handle page, String questionMnemonic, Handle item, String additionalInfoMarkup);
+
 }
